@@ -7,8 +7,7 @@ grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
   # 1. [Compute Markov Blankets]
   mb = smartSapply(cluster, as.list(nodes), gs.markov.blanket, data = x,
          nodes = nodes, alpha = alpha, B = B, whitelist = whitelist,
-         blacklist = blacklist, test = test, max.sx = max.sx,
-         complete = complete, debug = debug)
+         blacklist = blacklist, test = test, max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check markov blankets for consistency.
@@ -17,7 +16,7 @@ grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
   # 2. [Compute Graph Structure]
   mb = smartSapply(cluster, as.list(nodes), neighbour, mb = mb, data = x,
          alpha = alpha, B = B, whitelist = whitelist, blacklist = blacklist,
-         test = test, max.sx = max.sx, complete = complete, debug = debug)
+         test = test, max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check neighbourhood sets for consistency.
@@ -28,7 +27,7 @@ grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
 }#GROW.SHRINK
 
 gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
-  start = character(0), test, max.sx = ncol(x), complete, debug = FALSE) {
+  start = character(0), test, max.sx = ncol(x), debug = FALSE) {
 
   nodes = nodes[nodes != x]
   whitelisted = nodes[sapply(nodes,
@@ -78,8 +77,7 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
         cat("  * checking node", y, "for inclusion.\n")
 
 
-      a = indep.test(x, y, mb, data = data, test = test, B = B,
-            alpha = alpha, complete = complete)
+      a = indep.test(x, y, mb, data = data, test = test, B = B, alpha = alpha)
 
       if (a <= alpha) {
 
@@ -128,7 +126,7 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
         cat("  * checking node", y, "for exclusion (shrinking phase).\n")
 
       a = indep.test(x, y, mb[mb != y], data = data, test = test, B = B,
-            alpha = alpha, complete = complete)
+            alpha = alpha)
 
       if (a > alpha) {
 
