@@ -11,7 +11,7 @@ double maxw = 0;
   /* ensure the buffer is clean. */
   memset(w, '\0', n * sizeof(double));
   /* compute log-probabilities for each particle. */
-  c_entropy_loss(fitted, data, n, TRUE, w, keep, FALSE, FALSE, debugging);
+  c_entropy_loss(fitted, data, n, TRUE, w, NULL, keep, FALSE, FALSE, debugging);
   /* rescale before exponentiating them into probabilities (if possible). */
   max_el = d_which_max(w, n);
 
@@ -29,18 +29,3 @@ double maxw = 0;
 
 }/*C_LW_WEIGHTS*/
 
-SEXP lw_weights(SEXP fitted, SEXP data, SEXP keep, SEXP debug) {
-
-int n = length(VECTOR_ELT(data, 0));
-SEXP weights;
-
-  PROTECT(weights = allocVector(REALSXP, n));
-
-  c_lw_weights(fitted, data, n, REAL(weights), keep, isTRUE(debug));
-
-  UNPROTECT(1);
-
-  return weights;
-
-}/*LW_WEIGHTS*/
-
